
rm(list = ls())

# install.packages()  #### to install new packages before opening them with 'library()'
library(ggplot2)
library(tidyverse)
library(patchwork)
library(data.table)
library(ggpubr)
library(dplyr)
library(ggExtra)
library(EnvStats)


############## Flow-cytometry counting - droplets and 96 well plates ##############
##############  SUCCINATE 10mM  ##############


### ======================================================================
###  IMPORT DROPLETS DATA FRAMES - PROPORTION OF EMPTY/NON EMPTY DROPLETS
### ======================================================================

 
### Set working directory to location of script file (main folder)
setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) # location of script file (main folder)
getwd()

mainpath <- getwd()
# Split the path by '/'
pathComponents <- unlist(strsplit(mainpath, "/"))
# Get the length of the path components
numComponents <- length(pathComponents)
# Reconstruct the path up to the 3rd '/' from the end
# Note: We use paste with collapse to reconstruct the path
outputPath <- paste(pathComponents[1:(numComponents - 2)], collapse = "/")
setwd(outputPath); getwd()



### load the three tables for PPU/PVE on succinate in various droplets sizes or founder population sizes
DropletsF.40.small = read.table(paste0(getwd(),"/Figure8&S12-S14/results_plots/fc_counts_smalldroplets_ratios_table.csv"), sep = "," , header = T)
DropletsF.80.small = read.table(paste0(getwd(),"/Figure8&S12-S14/results_plots/fc_counts_bigdroplets_ratios_table.csv"), sep = "," , header = T)
DropletsF.80.large = read.table(paste0(getwd(),"/Figure8&S12-S14/results_plots/fc_counts_bigdroplets_bigpop_ratios_table.csv"), sep = "," , header = T)

### =========================
###      POST PROCESSING
### =========================

### Adjust data structure to match the three tables's structure
DropletsF.40.small <- DropletsF.40.small %>% 
  pivot_wider(names_from = channel, values_from = Mean.concentration.biorep)
DropletsF.40.small <- DropletsF.40.small %>% rename(
  Biorep.Mean.CellConcentration.GFP = GFP,
  Biorep.Mean.CellConcentration.MCH = mCherry)
# Calculate ratios GFP cells / mCherry cells
DropletsF.40.small$ratio.gfp.on.mch <- DropletsF.40.small$Biorep.Mean.CellConcentration.GFP/DropletsF.40.small$Biorep.Mean.CellConcentration.MCH
# Change Condition categories name
DropletsF.40.small <- DropletsF.40.small %>% 
  mutate(Condition2 = case_when(
    Condition == 'med' ~ 'MEDIUM',
    Condition == 'Ppu' ~ 'PPU',
    Condition == 'Pve' ~ 'PVE',
    Condition == 'PpPv' ~ 'MIX'
  ))
DropletsF.40.small$Condition = DropletsF.40.small$Condition2 ; DropletsF.40.small$Condition2 <- NULL

# Add a new condition column to distinguish the data from the three tables
DropletsF.40.small <- DropletsF.40.small %>% mutate(second.condition = '40µm small')
DropletsF.80.small <- DropletsF.80.small %>% mutate(second.condition = '80µm small')
DropletsF.80.large <- DropletsF.80.large %>% mutate(second.condition = '80µm large')

# Fuse the three tables
fc.count <- rbind(DropletsF.40.small, DropletsF.80.small, DropletsF.80.large)


### Relative total PVE cell/concentration
fc.count$relative.pve.cell.count <- fc.count$Biorep.Mean.CellConcentration.MCH / (fc.count$Biorep.Mean.CellConcentration.MCH + fc.count$Biorep.Mean.CellConcentration.GFP)


### ==========================
###           PlOTS
### ==========================

### Biomass ratios

fc.count$second_condition_culture <- paste(fc.count$second.condition, fc.count$Culture, sep = " ")
fc.count_mix <- fc.count %>% 
  filter(DilutionFactor == 3, Condition == 'MIX') %>% 
  mutate(factor = fct_relevel(second_condition_culture, "40µm small droplet",  "80µm small droplets", "40µm small plate", "80µm large droplets"))

# Calculate the mean of observed variances for each condition
mean_data <- aggregate(relative.pve.cell.count ~ second_condition_culture , data = fc.count_mix, FUN = mean)
stderr_data <- aggregate(relative.pve.cell.count ~ second_condition_culture, data = fc.count_mix, FUN = sd )
mean_stderr_data <- merge(mean_data, stderr_data, by = c("second_condition_culture"))
mean_stderr_data <- mean_stderr_data %>% mutate(factor2 = fct_relevel(second_condition_culture, "40µm small droplet",  "80µm small droplets", "40µm small plate", "80µm large droplets"))

### plot
relative.pve.biomass <- ggplot(mean_stderr_data, aes(x = factor2, y = relative.pve.cell.count.x))+
  geom_col(fill = '#F7D002')+
  geom_errorbar(aes(ymin = relative.pve.cell.count.x - relative.pve.cell.count.y, ymax = relative.pve.cell.count.x + relative.pve.cell.count.y), position = position_dodge(width = 0.9), width = 0.25) +
  labs(y = 'Total PVE relative abundance', x = 'Starting condition')+
 # geom_jitter(data = fc.count_mix, aes(x = factor, y = relative.pve.cell.count), width = 0.15, height = 0, size = 2)+
  theme_bw(); relative.pve.biomass

# save plot
pdf(paste0(getwd(),'/Figure8&S12-S14/results_plots/Fig8_J.pdf'), width=3 , height=3.5)
relative.pve.biomass
dev.off()


### ANOVA test

names(fc.count_mix)

# check normality 
shapiro.test(fc.count_mix$relative.pve.cell.count)
# Fit the ANOVA model
anova_model <- aov(relative.pve.cell.count ~ factor, data = fc.count_mix)
# Summarize the ANOVA results
summary(anova_model)
# HSD Tukey Post-Hoc test
TukeyHSD(anova_model)











