
rm(list = ls())


library(ggExtra)
library(ggplot2)
library(tidyverse)
library(dplyr)
library(patchwork)
library(data.table)
library(ggpubr)
library(sf)
library(EnvStats)


### set working directory
setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) # location of script file (main folder)
getwd()

mainpath <- getwd()
# Split the path by '/'
pathComponents <- unlist(strsplit(mainpath, "/"))
# Get the length of the path components
numComponents <- length(pathComponents)
# Reconstruct the path up to the 3rd '/' from the end
# Note: We use paste with collapse to reconstruct the path
outputPath <- paste(pathComponents[1:(numComponents - 2)], collapse = "/")
setwd(outputPath); getwd()



### ===============================
###    POISSON DISTRIBUTED CELLS
### ===============================

### load data table
result_table_pois <- read.table(paste0(getwd(),"/results_plots/poisson_samedropsize_table_results.csv"), sep = "," , header = T)
head(result_table_pois)

### Post-processing
result_table_pois$PVE_biomass_proportion <- result_table_pois$biomass_PVE/(result_table_pois$biomass_PVE + result_table_pois$biomass_PPU)

result_table_pois2 <-  result_table_pois %>% 
  mutate(Species = case_when(
    biomass_PVE == 0 & biomass_PPU > 0 ~ 'PPU',
    biomass_PVE > 0 & biomass_PPU == 0 ~ 'PVE',
    biomass_PVE > 0 & biomass_PPU > 0 ~ "PPU PVE")) %>% 
  mutate(droplet_volume = case_when(
    population_size == 3 ~ 33.5,
    population_size == 10 ~ 33.5*(10/3),
    population_size == 100 ~ 33.5*(100/3)))

result_table_pois2$population_size <- as.factor(result_table_pois2$population_size)
result_table_pois2 <- result_table_pois2 %>% 
  mutate(factor = fct_relevel(population_size, "3", "10","100")) # Add a 'factor' column to plot mono-culture before mix-culture


### ===============================
###   UNIFORMLY DISTRIBUTED CELLS
### ===============================

### load data table
result_table_unif <- read.table(paste0(getwd(),"/results_plots/uniform_samedropsize_table_results.csv"), sep = "," , header = T)
head(result_table_unif)

### Post-processing
result_table_unif$PVE_biomass_proportion <- result_table_unif$biomass_PVE/(result_table_unif$biomass_PVE + result_table_unif$biomass_PPU)

result_table_unif2 <-  result_table_unif %>% 
  mutate(Species = case_when(
    biomass_PVE == 0 & biomass_PPU > 0 ~ 'PPU',
    biomass_PVE > 0 & biomass_PPU == 0 ~ 'PVE',
    biomass_PVE > 0 & biomass_PPU > 0 ~ "PPU PVE")) %>% 
  mutate(droplet_volume = case_when(
    population_size == 3 ~ 33.5,
    population_size == 10 ~ 33.5*(10/3),
    population_size == 100 ~ 33.5*(100/3)))

result_table_unif2$population_size <- as.factor(result_table_unif2$population_size)
result_table_unif2 <- result_table_unif2 %>% 
  mutate(factor = fct_relevel(population_size, "3", "10","100")) # Add a 'factor' column to plot mono-culture before mix-culture



### ===============================
###   Plot droplet productivities
### ===============================


# Plot constant + poisson side by side
result_table_pois2 <- result_table_pois2 %>% mutate(distribution = 'poisson')
result_table_unif2 <- result_table_unif2 %>% mutate(distribution = 'constant')
all.data <- rbind(result_table_pois2, result_table_unif2)

# Reorder the levels of the 'distribution' factor
all.data$distribution <- factor(all.data$distribution, levels = c("poisson", "constant"))

jitter.all <- ggplot(all.data, aes(x = factor, y = PVE_biomass_proportion, color = distribution))+
  geom_jitter(position = position_jitterdodge(jitter.width = 0.65, dodge.width = 0.82), alpha = 0.2)+
  geom_violin(position = position_dodge(width = 0.82), aes(fill = distribution), color = 'grey15', alpha = 0.3, draw_quantiles = c(0.25, 0.5, 0.75))+
  theme_bw()+
  scale_color_manual(values = c("poisson" = "skyblue4", "constant" = "skyblue2"))+
  scale_fill_manual(values = c("poisson" = 'grey90', "constant" = 'grey90')) + 
  labs(x = 'Starting population size (per species)', y = 'PVE relative biomass'); jitter.all

pdf(paste0(getwd(),'/results_plots/Fig8_D.pdf'), width=5.5 , height=3.5)
jitter.all
dev.off()  


### =====================================================================
###                           Dominance score
### =====================================================================


# poisson distribution
n = 1
pve.dominance.pois <- data.frame('cell_distribution' = numeric(0), 'replicate' = numeric(0), 'starting_pop_size' = numeric(0),  'pve_dominance' = numeric(0))
for (i in unique(result_table_pois2$replicate)) {
  for (j in unique(result_table_pois2$factor)) {
    data <- result_table_pois2 %>% filter(replicate == i & factor == j & Species == 'PPU PVE')
    pve.dom <- nrow(data[which(data$PVE_biomass_proportion > 0.5),])/nrow(data); pve.dom
    pve.dominance.pois[n,'cell_distribution'] <- 'poisson'
    pve.dominance.pois[n,'replicate'] <- i
    pve.dominance.pois[n,'starting_pop_size'] <- j
    pve.dominance.pois[n,'pve_dominance'] <- pve.dom
    n <- n +1
  }
}

# uniform distribution
n = 1
pve.dominance.unif <- data.frame('cell_distribution' = numeric(0), 'replicate' = numeric(0),'starting_pop_size' = numeric(0), 'pve_dominance' = numeric(0))
for (i in unique(result_table_unif2$replicate)) {
  for (j in unique(result_table_unif2$factor)) {
    data <- result_table_unif2 %>% filter(replicate == i & factor == j & Species == 'PPU PVE')
    pve.dom <- nrow(data[which(data$PVE_biomass_proportion > 0.5),])/nrow(data); pve.dom
    pve.dominance.unif[n,'cell_distribution'] <- 'uniform'
    pve.dominance.unif[n,'replicate'] <- i
    pve.dominance.unif[n,'starting_pop_size'] <- j
    pve.dominance.unif[n,'pve_dominance'] <- pve.dom
    n <- n +1
  }
}

# concatenate data-frames
pve.dominance <- rbind(pve.dominance.unif, pve.dominance.pois)
pve.dominance <- pve.dominance %>% 
  mutate(factor = fct_relevel(starting_pop_size, "3", "10","100")) # Add a 'factor' column to plot mono-culture before mix-culture

# Calculate the mean of observed values for each condition
mean_data <- aggregate(pve_dominance ~ factor + cell_distribution, data = pve.dominance, FUN = mean)
stderr_data <- aggregate(pve_dominance ~ factor + cell_distribution, data = pve.dominance, FUN = sd)
mean_stderr_data <- merge(mean_data, stderr_data, by = c("factor", "cell_distribution"))

# Create a barplot
pve.dom <- ggplot(mean_stderr_data, aes(x = factor, y = pve_dominance.x, fill = cell_distribution)) +
  geom_col(position = 'dodge') +
  geom_errorbar(aes(ymin = pve_dominance.x - pve_dominance.y, ymax = pve_dominance.x + pve_dominance.y),
                position = position_dodge(width = 0.9), width = 0.25) +
  labs(x = "Starting cells / species", y = "PVE dominated droplets (%)", fill = 'Starting cell distribution') +
  ggtitle("PVE dominance") +
  theme_bw(); pve.dom

### save plot
pdf(paste0(getwd(),'/results_plots/Fig8_D_subplot_histogram.pdf'), width=5.25 , height=3.5)
pve.dom
dev.off()

### =====================================================================
###                           Variance in data
### =====================================================================
n = 1
variance.pois <- data.frame('cell_distribution' = numeric(0), 'replicate' = numeric(0), 'starting_pop_size' = numeric(0),  'pve_relative_biomass_variance' = numeric(0))
variance.unif <- data.frame('cell_distribution' = numeric(0), 'replicate' = numeric(0),'starting_pop_size' = numeric(0), 'pve_relative_biomass_variance' = numeric(0))

for (i in unique(result_table_pois2$replicate)) {
  for (j in unique(result_table_pois2$factor)) {
    data_pois <- result_table_pois2 %>% filter(replicate == i & factor == j & Species == 'PPU PVE')
    data_unif <- result_table_unif2 %>% filter(replicate == i & factor == j & Species == 'PPU PVE')
    
    pve.var.pois <- var(data_pois$PVE_biomass_proportion); pve.var.pois
    pve.var.unif <- var(data_unif$PVE_biomass_proportion); pve.var.unif
    
    variance.pois[n,'cell_distribution'] <- 'poisson'
    variance.pois[n,'replicate'] <- i
    variance.pois[n,'starting_pop_size'] <- j
    variance.pois[n,'pve_relative_biomass_variance'] <- pve.var.pois
    
    variance.unif[n,'cell_distribution'] <- 'uniform'
    variance.unif[n,'replicate'] <- i
    variance.unif[n,'starting_pop_size'] <- j
    variance.unif[n,'pve_relative_biomass_variance'] <- pve.var.unif
    n <- n +1 
  }
}
variance.df <- rbind(variance.pois, variance.unif)
variance.df <- variance.df %>% 
  mutate(factor = fct_relevel(starting_pop_size, "3", "10","100")) # Add a 'factor' column to plot mono-culture before mix-culture

# Calculate the mean of observed variances for each condition
mean_data <- aggregate(pve_relative_biomass_variance ~ factor + cell_distribution, data = variance.df, FUN = mean)
stderr_data <- aggregate(pve_relative_biomass_variance ~ factor + cell_distribution, data = variance.df, FUN = sd)
mean_stderr_data <- merge(mean_data, stderr_data, by = c("factor", "cell_distribution"))

# Create a barplot
pve.var <- ggplot(mean_stderr_data, aes(x = factor, y = pve_relative_biomass_variance.x, fill = cell_distribution)) +
  geom_col(position = 'dodge') +
  geom_errorbar(aes(ymin = pve_relative_biomass_variance.x - pve_relative_biomass_variance.y, ymax = pve_relative_biomass_variance.x + pve_relative_biomass_variance.y),
                position = position_dodge(width = 0.9), width = 0.25) +
  labs(x = "Starting cells / species", y = "Var (PVE relative biomass)", fill = 'Starting cell distribution') +
  ggtitle("Mix-growth heterogeneity") +
  theme_bw(); pve.var

### save plot
pdf(paste0(getwd(),'/results_plots/Fig8_E.pdf'), width=5.25 , height=3.5)
pve.var
dev.off()


### Anova + Post Hoc test
names(variance.df)
variance.df$merged.cond <- paste(variance.df$cell_distribution, variance.df$factor, sep = '_')
split_data <- split(variance.df$pve_relative_biomass_variance, variance.df$merged.cond)
# Apply Shapiro-Wilk test to each group and store the results in a list
shapiro_results <- lapply(split_data, shapiro.test); shapiro_results

# Anova - poisson distrib
dat <- variance.df %>% filter(cell_distribution == 'poisson')
anova_test <- aov(pve_relative_biomass_variance ~ merged.cond, data = dat)
summary(anova_test)
# Anova - constant distrib
dat2 <- variance.df %>% filter(cell_distribution == 'uniform')
anova_test <- aov(pve_relative_biomass_variance ~ merged.cond, data = dat2)
summary(anova_test)




### =====================================================================
### Check now the effect on the total biomass across fragmented habitat - MIX DROPLETS ONLY
### =====================================================================

n = 1
tot.biomass.pois <- data.frame('cell_distribution' = numeric(0), 'replicate' = numeric(0), 'starting_pop_size' = numeric(0))
tot.biomass.unif <- data.frame('cell_distribution' = numeric(0), 'replicate' = numeric(0),'starting_pop_size' = numeric(0))

for (i in unique(result_table_pois2$replicate)) {
  for (j in unique(result_table_pois2$factor)) {
    data_pois <- result_table_pois2 %>% filter(replicate == i & factor == j & Species == 'PPU PVE')
    data_unif <- result_table_unif2 %>% filter(replicate == i & factor == j & Species == 'PPU PVE')

    tot.biomass.pois[n,'cell_distribution'] <- 'poisson'
    tot.biomass.pois[n,'replicate'] <- i
    tot.biomass.pois[n,'starting_pop_size'] <- j
    tot.biomass.pois[n,'total_pve_biomass'] <- sum(data_pois$biomass_PVE)
    tot.biomass.pois[n,'total_ppu_biomass'] <- sum(data_pois$biomass_PPU)
    tot.biomass.pois[n,'nb_coculture_droplets'] <- unique(data_pois$nb_coculture_droplets)
    tot.biomass.pois[n,'droplet_volume'] <- unique(data_pois$droplet_volume)
  
    tot.biomass.unif[n,'cell_distribution'] <- 'uniform'
    tot.biomass.unif[n,'replicate'] <- i
    tot.biomass.unif[n,'starting_pop_size'] <- j
    tot.biomass.unif[n,'total_pve_biomass'] <- sum(data_unif$biomass_PVE)
    tot.biomass.unif[n,'total_ppu_biomass'] <- sum(data_unif$biomass_PPU)
    tot.biomass.unif[n,'nb_coculture_droplets'] <- unique(data_unif$nb_coculture_droplets)
    tot.biomass.unif[n,'droplet_volume'] <- unique(data_unif$droplet_volume)
      
    n <- n +1 
  }
}
tot.biomass.df <- rbind(tot.biomass.pois, tot.biomass.unif)
tot.biomass.df <- tot.biomass.df %>% 
  mutate(factor = fct_relevel(starting_pop_size, "3", "10","100")) 
# total volume analyzed in µL
tot.biomass.df$total_vol_µL <- (tot.biomass.df$nb_coculture_droplets * tot.biomass.df$droplet_volume)
# total species concentrations (cells/mL)
tot.biomass.df$pve_biomass_concentration_g_ml <- (tot.biomass.df$total_pve_biomass/tot.biomass.df$total_vol_µL)*10^9
tot.biomass.df$ppu_biomass_concentration_g_ml <- (tot.biomass.df$total_ppu_biomass/tot.biomass.df$total_vol_µL)*10^9
# relative abundance pve
tot.biomass.df$pve_relative_biom <- tot.biomass.df$total_pve_biomass/(tot.biomass.df$total_ppu_biomass + tot.biomass.df$total_pve_biomass)


# Calculate the mean of observed relative abundances for each condition
mean_data <- aggregate(pve_relative_biom ~ factor + cell_distribution, data = tot.biomass.df, FUN = mean)
stderr_data <- aggregate(pve_relative_biom ~ factor + cell_distribution, data = tot.biomass.df, FUN = sd)
mean_stderr_data <- merge(mean_data, stderr_data, by = c("factor", "cell_distribution"))


total_rel_biomass <- ggplot(mean_stderr_data, aes(x = factor, y = pve_relative_biom.x, fill = cell_distribution)) +
  geom_col(position = 'dodge') +
  geom_errorbar(aes(ymin = pve_relative_biom.x - pve_relative_biom.y, ymax = pve_relative_biom.x + pve_relative_biom.y),
                position = position_dodge(width = 0.9), width = 0.25) +
  labs(x = "Starting cells / species", y = "Total PVE relative biomass", fill = 'Starting cell distribution', title = 'Meta-community composition (mix droplets only)')+
  ylim(0, 0.45)+
  theme_bw(); total_rel_biomass

# save plot
pdf(paste0(getwd(),'/results_plots/FigS12_B.pdf'), width=5.25 , height=3.5)
total_rel_biomass
dev.off()


### Anova
names(tot.biomass.df)
tot.biomass.df$merged.cond <- paste(tot.biomass.df$cell_distribution, tot.biomass.df$factor, sep = '_')
split_data <- split(tot.biomass.df$pve_relative_biom, tot.biomass.df$merged.cond)
# Apply Shapiro-Wilk test to each group and store the results in a list
shapiro_results <- lapply(split_data, shapiro.test); shapiro_results
# Anova - poisson distrib
dat <- tot.biomass.df %>% filter(cell_distribution == 'poisson')
anova_test <- aov(pve_relative_biom ~ merged.cond, data = dat)
summary(anova_test)
# Anova - constant distrib
dat2 <- tot.biomass.df %>% filter(cell_distribution == 'uniform')
anova_test <- aov(pve_relative_biom ~ merged.cond, data = dat2)
summary(anova_test)


### =====================================================================
### Check now the effect on the total biomass across fragmented habitat - SOLO DROPLETS INCLUDED
### =====================================================================

n = 1
tot.biomass.pois <- data.frame('cell_distribution' = numeric(0), 'replicate' = numeric(0), 'starting_pop_size' = numeric(0))
tot.biomass.unif <- data.frame('cell_distribution' = numeric(0), 'replicate' = numeric(0),'starting_pop_size' = numeric(0))

for (i in unique(result_table_pois2$replicate)) {
  for (j in unique(result_table_pois2$factor)) {
    data_pois <- result_table_pois2 %>% filter(replicate == i & factor == j )
    data_unif <- result_table_unif2 %>% filter(replicate == i & factor == j )
    
    tot.biomass.pois[n,'cell_distribution'] <- 'poisson'
    tot.biomass.pois[n,'replicate'] <- i
    tot.biomass.pois[n,'starting_pop_size'] <- j
    tot.biomass.pois[n,'total_pve_biomass'] <- sum(data_pois$biomass_PVE)
    tot.biomass.pois[n,'total_ppu_biomass'] <- sum(data_pois$biomass_PPU)
    tot.biomass.pois[n,'nb_coculture_droplets'] <- unique(data_pois$nb_coculture_droplets)
    tot.biomass.pois[n,'droplet_volume'] <- unique(data_pois$droplet_volume)
    
    tot.biomass.unif[n,'cell_distribution'] <- 'uniform'
    tot.biomass.unif[n,'replicate'] <- i
    tot.biomass.unif[n,'starting_pop_size'] <- j
    tot.biomass.unif[n,'total_pve_biomass'] <- sum(data_unif$biomass_PVE)
    tot.biomass.unif[n,'total_ppu_biomass'] <- sum(data_unif$biomass_PPU)
    tot.biomass.unif[n,'nb_coculture_droplets'] <- unique(data_unif$nb_coculture_droplets)
    tot.biomass.unif[n,'droplet_volume'] <- unique(data_unif$droplet_volume)
    
    n <- n +1 
  }
}
tot.biomass.df <- rbind(tot.biomass.pois, tot.biomass.unif)
tot.biomass.df <- tot.biomass.df %>% 
  mutate(factor = fct_relevel(starting_pop_size, "3", "10","100")) 
# total volume analyzed in µL
tot.biomass.df$total_vol_µL <- (tot.biomass.df$nb_coculture_droplets * tot.biomass.df$droplet_volume)
# total species concentrations (cells/mL)
tot.biomass.df$pve_biomass_concentration_g_ml <- (tot.biomass.df$total_pve_biomass/tot.biomass.df$total_vol_µL)*10^9
tot.biomass.df$ppu_biomass_concentration_g_ml <- (tot.biomass.df$total_ppu_biomass/tot.biomass.df$total_vol_µL)*10^9
# relative abundance pve
tot.biomass.df$pve_relative_biom <- tot.biomass.df$total_pve_biomass/(tot.biomass.df$total_ppu_biomass + tot.biomass.df$total_pve_biomass)


# Calculate the mean of observed relative abundances for each condition
mean_data <- aggregate(pve_relative_biom ~ factor + cell_distribution, data = tot.biomass.df, FUN = mean)
stderr_data <- aggregate(pve_relative_biom ~ factor + cell_distribution, data = tot.biomass.df, FUN = sd)
mean_stderr_data <- merge(mean_data, stderr_data, by = c("factor", "cell_distribution"))


total_rel_biomass_withsolo <- ggplot(mean_stderr_data, aes(x = factor, y = pve_relative_biom.x, fill = cell_distribution)) +
  geom_col(position = 'dodge') +
  geom_errorbar(aes(ymin = pve_relative_biom.x - pve_relative_biom.y, ymax = pve_relative_biom.x + pve_relative_biom.y),
                position = position_dodge(width = 0.9), width = 0.25) +
  labs(x = "Starting cells / species", y = "Total PVE relative biomass", fill = 'Starting cell distribution', title = 'Meta-community composition (solo + mix droplets)')+
  ylim(0, 0.45)+
  theme_bw(); total_rel_biomass_withsolo

# save plot
pdf(paste0(getwd(),'/results_plots/Fig8_F.pdf'), width=5.25 , height=3.5)
total_rel_biomass_withsolo
dev.off()


### Anova
names(tot.biomass.df)
tot.biomass.df$merged.cond <- paste(tot.biomass.df$cell_distribution, tot.biomass.df$factor, sep = '_')
split_data <- split(tot.biomass.df$pve_relative_biom, tot.biomass.df$merged.cond)
# Apply Shapiro-Wilk test to each group and store the results in a list
shapiro_results <- lapply(split_data, shapiro.test); shapiro_results
# Anova - poisson distrib
dat <- tot.biomass.df %>% filter(cell_distribution == 'poisson')
anova_test <- aov(pve_relative_biom ~ merged.cond, data = dat)
summary(anova_test)
# Anova - constant distrib
dat2 <- tot.biomass.df %>% filter(cell_distribution == 'uniform')
anova_test <- aov(pve_relative_biom ~ merged.cond, data = dat2)
summary(anova_test)








